var ipersistent_8h =
[
    [ "IPersistent", "classSteinberg_1_1IPersistent.html", "classSteinberg_1_1IPersistent" ],
    [ "IAttributes", "classSteinberg_1_1IAttributes.html", "classSteinberg_1_1IAttributes" ],
    [ "IAttributes2", "classSteinberg_1_1IAttributes2.html", "classSteinberg_1_1IAttributes2" ],
    [ "IAttrID", "namespaceSteinberg.html#ae6eacc17e4382538d4af0d9993bc869a", null ]
];